@@ -46,9 +46,7 @@ class Experiment:
         else:
             raise Exception("Cannot attach repository.")
 
-    def add_cohort_to_repository(
-        self, overwrite=False, confirm_msg=True
-    ) -> None:
+    def add_cohort_to_repository(self, overwrite=False) -> dict:
         """Add cohort of students to repository.
 
         Parameters
@@ -57,8 +55,6 @@ class Experiment:
             Name of collection to which cohort will be added, by default "ds_applicants"
         overwrite : bool, optional
             Whether to overwrite collection if already exists, by default False
-        confirm_msg : bool, optional
-            Whether to print confirmation message, by default True
         """
         self.repo.create_collection(
             collection=self.collection, overwrite=overwrite
@@ -68,17 +64,9 @@ class Experiment:
             records=self.cohort.yield_students(),
             return_result=True,
         )
-        if confirm_msg:
-            if r["acknowledged"]:
-                print(
-                    f"Added {len(self.cohort._students)} students to repository."
-                )
-            else:
-                print(
-                    f"Failed to add {len(self.cohort._students)} students to repository."
-                )
+        return r
 
-    def run_experiment(self, days: int, start: Optional[str] = None) -> None:
+    def run_experiment(self, days: int, start: Optional[str] = None) -> dict:
         """Add experimental student data to repository.
 
         Parameters
@@ -89,9 +77,10 @@ class Experiment:
         if start is None:
             start = pd.Timestamp.now()
         self.cohort = Cohort(days=days, start=start, is_experiment=True)
-        self.add_cohort_to_repository()
+        r = self.add_cohort_to_repository()
+        return r
 
-    def reset_experiment(self, confirm_msg=True) -> None:
+    def reset_experiment(self) -> dict:
         """Remove experimental student data from repository.
 
         Parameters
@@ -104,5 +93,4 @@ class Experiment:
             query={"inExperiment": {"$exists": True}},
             return_result=True,
         )
-        if results["acknowledged"] and confirm_msg:
-            print(f"Deleted {results['deleted_count']} from repository.")
+        return results
